[seed] [docs] Standardize on 'val' for type conversion function input value



commit 723f390151903df2b2e3402032aee7677cab1092
Author: Tim Horton <hortont424 gmail com>
Date:   Mon Aug 10 06:40:00 2009 -0800

    [docs] Standardize on 'val' for type conversion function input value

 libseed/seed-types.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/libseed/seed-types.c b/libseed/seed-types.c
index 80215bf..7d5e72e 100644
--- a/libseed/seed-types.c
+++ b/libseed/seed-types.c
@@ -2063,7 +2063,7 @@ seed_value_to_filename (JSContextRef ctx,
 /**
  * seed_value_from_filename:
  * @ctx: A #SeedContext.
  * @filename: The #gchar* filename to represent.
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.
  *
@@ -2076,12 +2076,12 @@ seed_value_to_filename (JSContextRef ctx,
  */
 JSValueRef
 seed_value_from_filename (JSContextRef ctx,
-			  const gchar * filename, JSValueRef * exception)
+			  const gchar * val, JSValueRef * exception)
 {
   GError *e = NULL;
   gchar *utf8;
 
-  utf8 = g_filename_to_utf8 (filename, -1, NULL, NULL, &e);
+  utf8 = g_filename_to_utf8 (val, -1, NULL, NULL, &e);
 
   if (e)
     {
@@ -2063,7 +2063,7 @@ seed_value_to_filename (JSContextRef ctx,
  * seed_value_from_filename:
  * @ctx: A #SeedContext.
- * @filename: The #gchar* filename to represent.
+ * @val: The #gchar* filename to represent.
  * @exception: A reference to a #SeedValue in which to store any exceptions.
  *             Pass %NULL to ignore exceptions.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]